Class: Google::Apis::SecretmanagerV1beta2::Progress
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1beta2::Progress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1beta2/classes.rb,
lib/google/apis/secretmanager_v1beta2/representations.rb,
lib/google/apis/secretmanager_v1beta2/representations.rb
Overview
Represents progress information for operations involving multiple secret versions.
Instance Attribute Summary collapse
-
#completed_version_count ⇒ Fixnum
Output only.
-
#failed_version_count ⇒ Fixnum
Output only.
-
#total_version_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Progress
constructor
A new instance of Progress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Progress
Returns a new instance of Progress.
847 848 849 |
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_version_count ⇒ Fixnum
Output only. Number of secret versions that have been successfully processed
so far.
Corresponds to the JSON property completedVersionCount
834 835 836 |
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 834 def completed_version_count @completed_version_count end |
#failed_version_count ⇒ Fixnum
Output only. Number of secret versions that failed to process.
Corresponds to the JSON property failedVersionCount
839 840 841 |
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 839 def failed_version_count @failed_version_count end |
#total_version_count ⇒ Fixnum
Output only. Provides the total number of secret versions to be processed by
the operation.
Corresponds to the JSON property totalVersionCount
845 846 847 |
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 845 def total_version_count @total_version_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
852 853 854 855 856 |
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 852 def update!(**args) @completed_version_count = args[:completed_version_count] if args.key?(:completed_version_count) @failed_version_count = args[:failed_version_count] if args.key?(:failed_version_count) @total_version_count = args[:total_version_count] if args.key?(:total_version_count) end |