Class: Google::Apis::SecretmanagerV1beta2::SecretVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1beta2/classes.rb,
lib/google/apis/secretmanager_v1beta2/representations.rb,
lib/google/apis/secretmanager_v1beta2/representations.rb

Overview

A secret version resource in the Secret Manager API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretVersion

Returns a new instance of SecretVersion.



1220
1221
1222
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_specified_payload_checksumBoolean Also known as: client_specified_payload_checksum?

Output only. True if payload checksum specified in SecretPayload object has been received by SecretManagerService on SecretManagerService.AddSecretVersion. Corresponds to the JSON property clientSpecifiedPayloadChecksum

Returns:

  • (Boolean)


1170
1171
1172
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1170

def client_specified_payload_checksum
  @client_specified_payload_checksum
end

#create_timeString

Output only. The time at which the SecretVersion was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1176
1177
1178
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1176

def create_time
  @create_time
end

#customer_managed_encryptionGoogle::Apis::SecretmanagerV1beta2::CustomerManagedEncryptionStatus

Describes the status of customer-managed encryption. Corresponds to the JSON property customerManagedEncryption



1181
1182
1183
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1181

def customer_managed_encryption
  @customer_managed_encryption
end

#destroy_timeString

Output only. The time this SecretVersion was destroyed. Only present if state is DESTROYED. Corresponds to the JSON property destroyTime

Returns:

  • (String)


1187
1188
1189
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1187

def destroy_time
  @destroy_time
end

#etagString

Output only. Etag of the currently stored SecretVersion. Corresponds to the JSON property etag

Returns:

  • (String)


1192
1193
1194
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1192

def etag
  @etag
end

#nameString

Output only. The resource name of the SecretVersion in the format projects/*/ secrets/*/versions/*. SecretVersion IDs in a Secret start at 1 and are incremented for each subsequent version of the secret. Corresponds to the JSON property name

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1199

def name
  @name
end

#replication_statusGoogle::Apis::SecretmanagerV1beta2::ReplicationStatus

The replication status of a SecretVersion. Corresponds to the JSON property replicationStatus



1204
1205
1206
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1204

def replication_status
  @replication_status
end

#scheduled_destroy_timeString

Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time. Corresponds to the JSON property scheduledDestroyTime

Returns:

  • (String)


1213
1214
1215
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1213

def scheduled_destroy_time
  @scheduled_destroy_time
end

#stateString

Output only. The current state of the SecretVersion. Corresponds to the JSON property state

Returns:

  • (String)


1218
1219
1220
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1218

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
# File 'lib/google/apis/secretmanager_v1beta2/classes.rb', line 1225

def update!(**args)
  @client_specified_payload_checksum = args[:client_specified_payload_checksum] if args.key?(:client_specified_payload_checksum)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption = args[:customer_managed_encryption] if args.key?(:customer_managed_encryption)
  @destroy_time = args[:destroy_time] if args.key?(:destroy_time)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @replication_status = args[:replication_status] if args.key?(:replication_status)
  @scheduled_destroy_time = args[:scheduled_destroy_time] if args.key?(:scheduled_destroy_time)
  @state = args[:state] if args.key?(:state)
end